# The naming scheme in non-Mandriva-based distros
%if 0%{!?mklibname:1}
%define mklibname(ds)  lib%{1}%{?2:%{2}}%{-s:-static}%{-d:-devel}
%endif
%if 0%{!?mkrel:1}
%define mkrel(c) %{1}%{?dist}
%endif

# comment out if not pre rel
%define prerel rc4
Name:           sway
Version:        1.11
Release:        %mkrel %{?prerel:0.%{prerel}.}1
Summary:        i3-compatible window manager for Wayland
Group:          Graphical desktop/Other
License:        MIT
URL:            https://github.com/swaywm/sway
Source0:        %{url}/releases/download/%{version}%{?prerel:-%prerel}/%{name}-%{version}%{?prerel:-%prerel}.tar.gz
Source1:        %{url}/releases/download/%{version}%{?prerel:-%prerel}/%{name}-%{version}%{?prerel:-%prerel}.tar.gz.sig
# Drew DeVault (sway signing key) <sway@cmpwn.com>
# Imported from http://pgp.mit.edu/pks/lookup?op=vindex&search=0x52CB6609B22DA89A
# Source2:        gpgkey-9DDA3B9FA5D58DD5392C78E652CB6609B22DA89A.gpg
# 0FDE7BE0E88F5E48: emersion <contact@emersion.fr>
Source2:        https://emersion.fr/.well-known/openpgpkey/hu/dj3498u4hyyarh35rkjfnghbjxug6b19#/gpgkey-0FDE7BE0E88F5E48.gpg


BuildRequires:  cmake
BuildRequires:  gcc-c++
%if 0%{?gpgverify:1}
BuildRequires:  gnupg2
%endif
BuildRequires:  meson >= 0.60.0
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(glesv2)
BuildRequires:  pkgconfig(json-c) >= 0.13
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libevdev)
BuildRequires:  pkgconfig(libinput) >= 1.21.0
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(libsystemd) >= 239
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(scdoc)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-server) >= 1.21.0
BuildRequires:  pkgconfig(wayland-protocols) >= 1.24
BuildRequires:  pkgconfig(wlroots-0.19)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-icccm)
BuildRequires:  pkgconfig(xkbcommon)
# wmenu is the default launcher in sway, but rofi is much better
Recommends:     rofi-wayland
# In addition, xargs is recommended for use in such a launcher arrangement
Recommends:     findutils
Recommends:     xdg-terminal-exec

Requires:       swaybg
Recommends:     swayidle
Recommends:     swaylock
# By default the Fedora background is used
Recommends:     desktop-backgrounds-compat

# Lack of graphical drivers may hurt the common use case
Recommends:     mesa-dri-drivers

# dmenu (as well as rxvt and many others) requires XWayland on Sway
Recommends:       x11-server-xwayland
# Sway binds the terminal shortcut to one specific terminal. We'll use
# xdg-terminal-exec so that Sway behaves like the rest of the system.
Recommends:     xdg-terminal-exec
# grim is the recommended way to take screenshots on sway 1.0+
Recommends:     grim

%description
Sway is a tiling window manager which supports the Wayland compositor protocol
and i3-compatible configuration.

%prep
%if 0%{?gpgverify:1}
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%endif
%autosetup -p1 -n %{name}-%{version}%{?prerel:-%prerel}

%build
%meson \
    -Dsd-bus-provider=libsystemd \
    -Dwerror=false
%meson_build

%install
%meson_install
# Set default terminal to urxvt256c-ml
sed -i 's/^set $term .*/set \$term xdg-terminal-exec/' %{buildroot}%{_sysconfdir}/sway/config
sed -i 's/^set $menu .*/set \$menu rofi -show run/' %{buildroot}%{_sysconfdir}/sway/config
%if 0%{?mageia}
# Set Mageia background as default background
sed -i "s|^output \* bg .*|output * bg /usr/share/mga/backgrounds/default.png fill|" %{buildroot}%{_sysconfdir}/sway/config
%endif

%files
%license LICENSE
%doc README.md
%dir %{_sysconfdir}/sway
%config(noreplace) %{_sysconfdir}/sway/config
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_mandir}/man7/*
%{_bindir}/sway
%{_bindir}/swaybar
%{_bindir}/swaymsg
%{_bindir}/swaynag
%{_datadir}/wayland-sessions/sway.desktop
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_sway*
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/sway*
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/sway*
%{_datadir}/backgrounds/sway
